pub unsafe extern "C-unwind" fn lua_absindex(
L: *mut lua_State,
idx: c_int,
) -> c_intExpand description
Transforms a stack index into an index that is not relative to the top of the stack.
Passing psuedo-indices or positive indices will return the same index, while negative indices will be transformed to a positive index.