pub unsafe extern "C-unwind" fn lua_call(
L: *mut lua_State,
nargs: c_int,
nresults: c_int,
)Expand description
Calls a function on the stack, with the given number of arguments, and the given number of results.
The function should be pushed onto the stack, and then the arguments should be pushed onto the stack above the function. The arguments and the function will be popped from the stack, and the results will be pushed onto the stack.
The nargs argument is the number of arguments to pass to the function,
and the nresults argument is the number of results to expect from the
function. If there are more results than nresults, the additional
results will be discarded. If there are fewer results than nresults,
the missing results will be filled with nil values.
If nresults is LUA_MULTRET, all results will be pushed onto the
stack.
Any errors that occur during the call will be propagated and this function will not return. If the function yields, this function will return.