pub unsafe extern "C-unwind" fn lua_cleartable( L: *mut lua_State, idx: c_int, )
Clears the table at the given index.
The table will be cleared of all values, but it will retain its allocated size and metatable.