pub unsafe extern "C-unwind" fn lua_clonetable(
L: *mut lua_State,
idx: c_int,
)Expand description
Clones the table at the given index and pushes it onto the stack.
All the table’s keys and values will be copied, the cloned table will have the same metatable and will not be readonly. The copy is shallow.