pub unsafe extern "C-unwind" fn lua_encodepointer(
L: *mut lua_State,
p: usize,
) -> usizeExpand description
Encodes a pointer such that it remains unique but no longer points to the original location.
This is useful for sandboxing pointers exposed to Luau.