lua_equal

Function lua_equal 

pub unsafe extern "C-unwind" fn lua_equal(
    L: *mut lua_State,
    idx1: c_int,
    idx2: c_int,
) -> c_int
Compares the values at the two indices for equality.

This function compares the values at the two indices for equality, using Luau’s equality rules (==).