pub unsafe extern "C-unwind" fn lua_getfenv(
L: *mut lua_State,
idx: c_int,
)Expand description
Gets the environment of the value at the given index and pushes it onto the top of the stack.
If the value at the given index does not have an environment, this
function will push nil onto the stack. If the value does have an
environment, it will be pushed onto the stack.
Only functions and threads have environments.