Function lua_getfield

pub unsafe extern "C-unwind" fn lua_getfield(
    L: *mut lua_State,
    idx: c_int,
    k: *const c_char,
) -> lua_Type
Indexes a table at the given index with the given string key and pushes the value onto the stack.

This function is equivalent to the Luau code t[k] where t is at the given index, and k is the given string key. The resulting value will be pushed onto the stack.

The type of the resulting value is returned.