Function lua_getmetatable

pub unsafe extern "C-unwind" fn lua_getmetatable(
    L: *mut lua_State,
    idx: c_int,
) -> c_int
Gets and pushes the metatable of the value at the given index onto the top of the stack.

If the value at the given index does not have a metatable, this function will not push anything onto the stack and will return 0. If the value does have a metatable, it will be pushed onto the stack and 1 will be returned.