lua_gettable

Function lua_gettable 

pub unsafe extern "C-unwind" fn lua_gettable(
    L: *mut lua_State,
    idx: c_int,
) -> lua_Type
Indexes a table at the given index with the key at the top of the stack and pushes the value onto the stack.

This function is equivalent to the Luau code t[k] where t is at the given index, and k is at the top of the stack. The key will be popped from the stack, and the resulting value will be pushed onto the stack.

The type of the resulting value is returned.