lua_getthreaddata

Function lua_getthreaddata 

pub unsafe extern "C-unwind" fn lua_getthreaddata(
    L: *mut lua_State,
) -> *mut c_void
Returns the thread-data pointer of the given thread.

This function returns the thread-data pointer of the given thread, which is null if the thread-data is unset, or the pointer previously set by lua_setthreaddata.