Function lua_gettop

pub unsafe extern "C-unwind" fn lua_gettop(L: *mut lua_State) -> c_int
Returns the number of items on the stack.

This function returns the top index of the stack, or the number of items on the stack. A return of 0 indicates that the stack is empty.