Function lua_getuserdatadtor

pub unsafe extern "C-unwind" fn lua_getuserdatadtor(
    L: *mut lua_State,
    tag: c_int,
) -> Option<lua_Destructor>
Gets the destructor of a userdata tag.

For all userdata with the same tag, the destructor will be called when the userdata is collected by the garbage collector.