Function lua_getuserdatametatable

pub unsafe extern "C-unwind" fn lua_getuserdatametatable(
    L: *mut lua_State,
    tag: c_int,
) -> c_int
Gets the metatable that userdata with the given tag will have when created with lua_newuserdatataggedwithmetatable.

The metatable will be pushed onto the top of the stack.