Function lua_insert

pub unsafe extern "C-unwind" fn lua_insert(
    L: *mut lua_State,
    idx: c_int,
)
Moves the value at the given index to the top of the stack.

This function moves the value at the given index to the top of the stack, shifting all values above it down by one.