Function lua_isyieldable

pub unsafe extern "C-unwind" fn lua_isyieldable(
    L: *mut lua_State,
) -> c_int
Returns if the thread is yieldable or not.

Threads may not yield when doing so would yield across a C call without a continuation, such as during a metamethod call.