Function lua_lessthan

pub unsafe extern "C-unwind" fn lua_lessthan(
    L: *mut lua_State,
    idx1: c_int,
    idx2: c_int,
) -> c_int
Compares the values at the two indices for less than.

This function compares the values at the two indices for less than, using Luau’s less than rules (<).

Greater than comparison can be done by swapping the indices.