Function lua_mainthread

pub unsafe extern "C-unwind" fn lua_mainthread(
    L: *mut lua_State,
) -> *mut lua_State
Returns the main thread of the given state.

This function returns the main thread of the given state, or the pointer initially returned by lua_newstate.