pub unsafe extern "C-unwind" fn lua_namecallatom(
L: *mut lua_State,
atom: *mut c_int,
) -> *const c_charExpand description
Returns the value of the namecall method string as well as its atom.
If not within a namecall context, this function will return null. Otherwise, it will return a pointer to the string.
If atom is not null, it will be set to the atom of the string.