lua_newbuffer

Function lua_newbuffer 

pub unsafe extern "C-unwind" fn lua_newbuffer(
    L: *mut lua_State,
    size: usize,
) -> *mut c_void
Pushes a new buffer onto the top of the stack.

This function will allocate a new buffer of the given size, push it onto the top of the stack, and return a pointer to the allocated buffer.