pub unsafe extern "C-unwind" fn lua_newthread(
L: *mut lua_State,
) -> *mut lua_StateExpand description
Creates a new thread.
This function creates a new thread, pushes it onto the stack, and returns the pointer to the new thread. Threads, like all other Luau objects, are subject to garbage collection.