Function lua_newuserdatatagged

pub unsafe extern "C-unwind" fn lua_newuserdatatagged(
    L: *mut lua_State,
    size: usize,
    tag: c_int,
) -> *mut c_void
Pushes a new userdata with a tag onto the top of the stack.

This function will allocate a new userdata of the given size, and push it onto the top of the stack. It will return a pointer to the allocated userdata.