lua_newuserdatataggedwithmetatable

Function lua_newuserdatataggedwithmetatable 

pub unsafe extern "C-unwind" fn lua_newuserdatataggedwithmetatable(
    L: *mut lua_State,
    size: usize,
    tag: c_int,
) -> *mut c_void
Pushes a new userdata with a tag and a metatable onto the top of the stack.

This function will allocate a new userdata of the given size, push it onto the top of the stack, and set its metatable to the table registered with the given tag. It will return a pointer to the allocated userdata.