pub unsafe extern "C-unwind" fn lua_pushinteger(
L: *mut lua_State,
n: lua_Integer,
)Expand description
Pushes an integer onto the top of the stack.
pub unsafe extern "C-unwind" fn lua_pushinteger(
L: *mut lua_State,
n: lua_Integer,
)Pushes an integer onto the top of the stack.