pub unsafe extern "C-unwind" fn lua_pushnumber(
L: *mut lua_State,
n: lua_Number,
)Expand description
Pushes a number onto the top of the stack.
pub unsafe extern "C-unwind" fn lua_pushnumber(
L: *mut lua_State,
n: lua_Number,
)Pushes a number onto the top of the stack.