pub unsafe extern "C-unwind" fn lua_pushthread( L: *mut lua_State, ) -> c_int
Pushes the thread onto the top of its own stack.
This function will return a 1 is this thread is the main thread of its state.