pub unsafe extern "C-unwind" fn lua_pushunsigned(
L: *mut lua_State,
n: lua_Unsigned,
)Expand description
Pushes an unsigned integer onto the top of the stack.
pub unsafe extern "C-unwind" fn lua_pushunsigned(
L: *mut lua_State,
n: lua_Unsigned,
)Pushes an unsigned integer onto the top of the stack.