Function lua_rawequal

pub unsafe extern "C-unwind" fn lua_rawequal(
    L: *mut lua_State,
    idx1: c_int,
    idx2: c_int,
) -> c_int
Compares the values at the two indices for raw equality.

This function compares the values at the two indices for raw equality, using Luau’s raw equality rules (does not hit metamethods).