lua_rawgeti

Function lua_rawgeti 

pub unsafe extern "C-unwind" fn lua_rawgeti(
    L: *mut lua_State,
    idx: c_int,
    k: c_int,
) -> lua_Type
Raw-indexes a table at the given index with the given integer key and pushes the value onto the stack.

This function is equivalent to the Luau code rawget(t, k) where t is at the given index, and k is the given integer key. The resulting value will be pushed onto the stack.

The type of the resulting value is returned.