lua_rawsetfield

Function lua_rawsetfield 

pub unsafe extern "C-unwind" fn lua_rawsetfield(
    L: *mut lua_State,
    idx: c_int,
    k: *const c_char,
)
Raw-sets a value in a table at the given index with the given string key.

This function is equivalent to the Luau code rawset(t, k, v) where t is at the given index, v is at the top of the stack, and k is the given string key.

The value will be popped from the stack.