lua_remove

Function lua_remove 

pub unsafe extern "C-unwind" fn lua_remove(
    L: *mut lua_State,
    idx: c_int,
)
Removes the value at the given index from the stack.

This function removes the value at the given index from the stack, shifting all values above it down by one.