pub unsafe extern "C-unwind" fn lua_resume(
L: *mut lua_State,
from: *mut lua_State,
nargs: c_int,
) -> lua_StatusExpand description
Resumes a thread with the given number of arguments.
This function will resume the thread with the given number of arguments. The arguments should be pushed onto the stack before calling resume.
The from argument is used to preserve the C call depth and limit. It
may be null, but this is bad practice.
This function returns the status of the resumed thread after it stops executing.