lua_settable

Function lua_settable 

pub unsafe extern "C-unwind" fn lua_settable(
    L: *mut lua_State,
    idx: c_int,
)
Sets a value in a table at the given index with the key at the top of stack.

This function is equivalent to the Luau code t[k] = v where t is at the given index, v is at the top of the stack, and k is right below v.

Both the key and value will be popped from the stack.