pub unsafe extern "C-unwind" fn lua_setthreaddata(
L: *mut lua_State,
data: *mut c_void,
)Expand description
Sets the thread-data pointer of the given thread.
This function sets the thread-data pointer of the given thread to the given pointer. The thread-data pointer is a pointer that can be used to store arbitrary data associated with the thread. It is not used by Luau itself, and is intended for use by C extensions.