lua_settop

Function lua_settop 

pub unsafe extern "C-unwind" fn lua_settop(
    L: *mut lua_State,
    idx: c_int,
)
Sets the top of the stack to the given index.

Accepts any index, including 0. If the index is greater than the current top, the stack will be extended with nil values.