pub unsafe extern "C-unwind" fn lua_setuserdatadtor(
L: *mut lua_State,
tag: c_int,
dtor: Option<lua_Destructor>,
)Expand description
Sets the destructor of a userdata tag.
For all userdata with the same tag, the destructor will be called when the userdata is collected by the garbage collector.