pub unsafe extern "C-unwind" fn lua_setuserdatametatable(
L: *mut lua_State,
tag: c_int,
)Expand description
Sets the metatable that userdata with the given tag will have when
created with lua_newuserdatataggedwithmetatable.
The metatable will be popped from the top of the stack.