Function lua_toboolean

pub unsafe extern "C-unwind" fn lua_toboolean(
    L: *mut lua_State,
    idx: c_int,
) -> c_int
Returns the truthiness of the value at the given index.

This function returns 0 if the value at the given index is nil or false, and 1 for all other values.