pub unsafe extern "C-unwind" fn lua_tobuffer(
L: *mut lua_State,
idx: c_int,
len: *mut usize,
) -> *mut c_voidExpand description
Returns the buffer at the given index.
If the value at the given index is not a buffer, this function will return null. Otherwise, it will return a pointer to the buffer’s data.
If len is not null, it will be set to the length of the buffer.