lua_tocfunction

Function lua_tocfunction 

pub unsafe extern "C-unwind" fn lua_tocfunction(
    L: *mut lua_State,
    idx: c_int,
) -> Option<lua_CFunction>
Returns a pointer to the C function at the given index.

If the value at the given index is not a C function, this function will return null. Otherwise, it will return a pointer to the C function.