pub unsafe extern "C-unwind" fn lua_tointegerx(
L: *mut lua_State,
idx: c_int,
isnum: *mut c_int,
) -> lua_IntegerExpand description
Attempts to convert the value at the given index to an integer.
This function operates similarly to lua_tonumberx, but adds the step
of flooring the result to an integer. While a string may be turned into
a number on the stack, the value on the stack will not be floored to an
integer.