lua_tolightuserdata

Function lua_tolightuserdata 

pub unsafe extern "C-unwind" fn lua_tolightuserdata(
    L: *mut lua_State,
    idx: c_int,
) -> *mut c_void
Returns the pointer of the light userdata at the given index.

If the value at the given index is not a light userdata, this function will return null. Otherwise, it will return the pointer that the light userdata contains.