pub unsafe extern "C-unwind" fn lua_tolstring(
L: *mut lua_State,
idx: c_int,
len: *mut usize,
) -> *const c_charExpand description
Attempts to convert the value at the given index to a string and returns its value and length.
This function attempts to convert the value at the given index to a string, returning a pointer to the string if successful, or null if the conversion failed.
If len is not null, it will be set to the length of the string if the
conversion was successful.
If the value is a string, it will be returned as is. If the value is a number, it will be converted into a string and the stack will be modified.