Function lua_tostringatom

pub unsafe extern "C-unwind" fn lua_tostringatom(
    L: *mut lua_State,
    idx: c_int,
    atom: *mut c_int,
) -> *const c_char
Returns the value of the string at the given index as well as its atom.

If the value at the given index is not a string, this function will return null. Otherwise, it will return a pointer to the string. Unlike lua_tolstring, this function does not do any conversions or modify the stack.

If atom is not null, it will be set to the atom of the string.