lua_tothread

Function lua_tothread 

pub unsafe extern "C-unwind" fn lua_tothread(
    L: *mut lua_State,
    idx: c_int,
) -> *mut lua_State
Returns the thread at the given index.

If the value at the given index is not a thread, this function will return null. Otherwise, it will return a pointer to the thread’s lua_State.