Function lua_xmove

pub unsafe extern "C-unwind" fn lua_xmove(
    from: *mut lua_State,
    to: *mut lua_State,
    n: c_int,
)
Moves values from the top of one stack to another stack.

This function moves n values from the top of the from stack to the top of the to stack. This can be thought of as a “slide” between the two stacks.