pub unsafe extern "C-unwind" fn lua_xpush(
from: *mut lua_State,
to: *mut lua_State,
idx: c_int,
)Expand description
Pushes a value from an index of one stack onto another stack.
This function pushes a copy of the value at the given index of the
from stack onto the top of the to stack.