pub struct lua_State { /* private fields */ }Expand description
Represents a Luau thread, stack, and environment. The main structure for interacting with the Luau VM.
This structure is opaque and should never exist, except as a pointer.