Type Alias lua_LibraryMemberTypeCallback

pub type lua_LibraryMemberTypeCallback = extern "C" fn(library: *const c_char, member: *const c_char) -> c_int;
A callback to retrieve the type of a member in a library, which is used to provide type information during native codegen.

Waiting on https://github.com/luau-lang/luau/discussions/1885 for more details on how this works.