#[repr(C)]pub enum lua_Status {
LUA_OK = 0,
LUA_YIELD = 1,
LUA_ERRRUN = 2,
LUA_ERRSYNTAX = 3,
LUA_ERRMEM = 4,
LUA_ERRERR = 5,
LUA_BREAK = 6,
}Expand description
The status codes returned by the Luau VM.
These codes indicate the result of a function call or operation in the Luau
VM. As an example lua_pcall might return LUA_OK if the call was
successful, or LUA_YIELD if the call yielded execution, or
LUA_ERRRUN if there was a runtime error.
Variants
LUA_OK = 0
The call was successful and the function returned normally.
LUA_YIELD = 1
The call yielded execution using either lua_yield or coroutine.yield.
LUA_ERRRUN = 2
The call encountered a runtime error.
LUA_ERRSYNTAX = 3
This variant exists only for backwards compatibility. It is not used.
LUA_ERRMEM = 4
The call encountered a memory allocation error.
LUA_ERRERR = 5
The call encountered an error while running the error handler.
LUA_BREAK = 6
The call was interrupted by a break.