pub unsafe extern "C-unwind" fn lua_checkstack(
L: *mut lua_State,
sz: c_int,
) -> c_intExpand description
Attempts to make space on the stack for at least n more values.
This function will attempt to make space on the stack for at least sz
more values. If the stack is already large enough, this function does
nothing. If the stack is not large enough, it will attempt to grow the
stack to accommodate the new values.
If the stack cannot be grown, this function will return 0, otherwise
it will return 1.