pub unsafe extern "C-unwind" fn lua_concat(
L: *mut lua_State,
n: c_int,
)Expand description
Concatenates n values from the stack into a string.
This function pops n values from the top of the stack, concatenates
them into a string, and pushes the resulting string onto the top of the
stack. When n is 0 an empty string is pushed onto the stack.