Function lua_encodepointer

pub unsafe extern "C-unwind" fn lua_encodepointer(
    L: *mut lua_State,
    p: usize,
) -> usize
Encodes a pointer such that it remains unique but no longer points to the original location.

This is useful for sandboxing pointers exposed to Luau.