pub unsafe extern "C-unwind" fn lua_equal(
L: *mut lua_State,
idx1: c_int,
idx2: c_int,
) -> c_intExpand description
Compares the values at the two indices for equality.
This function compares the values at the two indices for equality, using
Luau’s equality rules (==).