Function lua_error

pub unsafe extern "C-unwind" fn lua_error(L: *mut lua_State) -> !
Throws an error.

This function will throw an error with the top value on the stack being the error value. This function will not return.