pub unsafe fn lua_getref(L: *mut lua_State, ref: c_int) -> lua_TypeExpand description
Pushes the value of the given reference onto the stack.
This function will push the value of the given reference onto the stack and
return the type of the value. If the reference is LUA_NOREF or
LUA_REFNIL, this function will push nil onto the stack and return
LUA_TNIL.