pub unsafe extern "C-unwind" fn lua_insert(
L: *mut lua_State,
idx: c_int,
)Expand description
Moves the value at the given index to the top of the stack.
This function moves the value at the given index to the top of the stack, shifting all values above it down by one.