pub fn lua_ispseudo(i: c_int) -> bool
Checks if the given index is a pseudo-index.
This function checks if the given index is a pseudo-index, which includes the registry, environment, and global environment indices.