pub unsafe extern "C-unwind" fn lua_lightuserdatatag(
L: *mut lua_State,
idx: c_int,
) -> c_intExpand description
Returns the tag of the light userdata at the given index.
If the value at the given index is not a light userdata, this function
will return -1. Otherwise, it will return the tag of the light
userdata.