pub unsafe extern "C-unwind" fn lua_newuserdatadtor(
L: *mut lua_State,
size: usize,
dtor: Option<extern "C-unwind" fn(*mut c_void)>,
) -> *mut c_voidExpand description
Pushes a new userdata with a destructor onto the top of the stack.
This function will allocate a new userdata of the given size, push it onto the top of the stack, and set its destructor to the given function. It will return a pointer to the allocated userdata.