pub unsafe extern "C-unwind" fn lua_rawseti(
L: *mut lua_State,
idx: c_int,
k: c_int,
) -> c_intExpand description
Raw-sets a value in a table at the given index with the given integer key.
This function is equivalent to the Luau code rawset(t, k, v) where t
is at the given index, v is at the top of the stack, and k is the
given integer key.
The value will be popped from the stack.