pub unsafe extern "C-unwind" fn lua_replace(
L: *mut lua_State,
idx: c_int,
)Expand description
Replaces the given index with the value at the top of the stack.
This function replaces the value at the given index with the value at the top of the stack, and then pops the top value off the stack.