pub unsafe extern "C-unwind" fn lua_resumeerror(
L: *mut lua_State,
from: *mut lua_State,
) -> lua_StatusExpand description
Resumes a thread with an error.
This function is similar to lua_resume, but it will resume the
thread with an error. The error value is whatever is at the top of the
stack.
The from argument is used to preserve the C call depth and limit. It
may be null, but this is bad practice.
This function returns the status of the resumed thread after it stops executing.