pub unsafe extern "C-unwind" fn lua_setmemcat(
L: *mut lua_State,
category: c_int,
)Expand description
Sets the memory category of the thread.
All memory allocated by the thread will be counted towards this category, which can be used to track memory usage of different parts of the program.