pub unsafe extern "C-unwind" fn lua_tolightuserdatatagged(
L: *mut lua_State,
idx: c_int,
tag: c_int,
) -> *mut c_voidExpand description
Returns the pointer to the light userdata at the given index if it has the given tag.
If the value at the given index is not a light userdata, or if it does not have the given tag, this function will return null. Otherwise, it will return the pointer that the light userdata contains.