pub unsafe extern "C-unwind" fn lua_tolstringatom(
L: *mut lua_State,
idx: c_int,
len: *mut usize,
atom: *mut c_int,
) -> *const c_charExpand description
Returns the value of the string at the given index as well as its atom and length.
If the value at the given index is not a string, this function will
return null. Otherwise, it will return a pointer to the string. Unlike
lua_tolstring, this function does not do any conversions or modify
the stack.
If atom is not null, it will be set to the atom of the string. If
len is not null, it will be set to the length of the string.