pub unsafe fn lua_tounsigned(L: *mut lua_State, idx: c_int) -> lua_UnsignedExpand description
Attempts to convert the value at the given index to an unsigned integer, and returns it.
This function operates in the same way as lua_tointeger, but it will
return an unsigned integer instead. If the input is negative, the output
is undefined.