pub unsafe extern "C-unwind" fn lua_tounsignedx(
L: *mut lua_State,
idx: c_int,
isnum: *mut c_int,
) -> lua_UnsignedExpand description
Attempts to convert the value at the given index to an unsigned integer.
This function operates in the exact same way as lua_tointegerx, but
returns a lua_Unsigned instead of a lua_Integer. If the value
is negative the output is undefined.