pub unsafe extern "C-unwind" fn lua_touserdata(
L: *mut lua_State,
idx: c_int,
) -> *mut c_voidExpand description
Returns the pointer to the userdata at the given index.
If the value at the given index is not a userdata, this function will return null. Otherwise, it will return a pointer to the userdata.