pub unsafe extern "C-unwind" fn lua_tovector(
L: *mut lua_State,
idx: c_int,
) -> *const c_floatExpand description
Returns the value of the vector at the given index.
If the value at the given index is not a vector, this function will return null. Otherwise, it will return a pointer to the vector’s floats.