pub unsafe extern "C-unwind" fn lua_yield(
L: *mut lua_State,
nresults: c_int,
) -> c_intExpand description
Yields the thread with the given number of results.
This function will yield the thread, yielding the given number of results to the resumer. This function should only be called from return positions of C functions.