pub unsafe extern "C-unwind" fn luau_load(
L: *mut lua_State,
chunkname: *const c_char,
data: *const c_char,
size: usize,
env: c_int,
) -> c_intExpand description
Pushes a function constructed from bytecode onto the top of the stack.
This function will push a function onto the top of the stack, which is constructed from the given bytecode. The bytecode is expected to be in the format produced by the Luau compiler.
The env argument is the index of the environment table to use for the
function. If env is 0, the function will use the current environment
of the state.