pub type lua_CFunction = extern "C-unwind" fn(L: *mut lua_State) -> c_int;
The type of a C function that can be called from Luau.
This function takes a pointer to a lua_State and returns the number of results it pushes onto the stack. It can also yield execution, in which case it should return the result from lua_yield.
lua_State
lua_yield