pub type lua_LibraryMemberConstantCallback = extern "C" fn(library: *const c_char, member: *const c_char, constant: *mut lua_CompileConstant);Expand description
Allows the configuration of a constant in a library at compile time. This enables the compiler to optimize code with constant folding and other optimizations.